@@ -1,7 +1,7 @@
 /*
  * file - file I/O routines callable by users
  *
- * Copyright (C) 1999  David I. Bell and Landon Curt Noll
+ * Copyright (C) 1999-2007,2014  David I. Bell and Landon Curt Noll
  *
  * Primary author:  David I. Bell
  *
@@ -17,11 +17,7 @@
  * A copy of version 2.1 of the GNU Lesser General Public License is
  * distributed with calc under the filename COPYING-LGPL.  You should have
  * received a copy with calc; if not, write to Free Software Foundation, Inc.
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
- *
- * @(#) $Revision: 29.5 $
- * @(#) $Id: file.h,v 29.5 2001/06/08 21:00:58 chongo Exp $
- * @(#) $Source: /usr/local/src/cmd/calc/RCS/file.h,v $
+ * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  * Under source code control:	1996/05/24 05:55:58
  * File existed as early as:	1996
@@ -31,8 +27,8 @@
  */
 
 
-#if !defined(__FILE_H__)
-#define __FILE_H__
+#if !defined(INCLUDE_FILE_H)
+#define INCLUDE_FILE_H
 
 
 #if defined(CALC_SRC)	/* if we are building from the calc source tree */
@@ -53,8 +49,10 @@ typedef struct {
 	char *name;		/* file name */
 	BOOL reading;		/* TRUE if opened for reading */
 	BOOL writing;		/* TRUE if opened for writing */
+	BOOL appending;		/* TRUE if also opened for appending */
+	BOOL binary;		/* TRUE if binary mode - mode ignored/unused */
 	char action;		/* most recent use for 'r', 'w' or 0 */
-	char mode[sizeof("rb+")];/* open mode */
+	char mode[sizeof("rb+")+1];/* open mode */
 } FILEIO;
 
 
@@ -89,11 +87,13 @@ typedef struct {
 /*
  * external functions
  */
-extern FILEIO * findid(FILEID id, int writable);
-extern int fgetposid(FILEID id, FILEPOS *ptr);
-extern int fsetposid(FILEID id, FILEPOS *ptr);
-extern int get_open_siz(FILE *fp, ZVALUE *res);
-extern char* findfname(FILEID);
+E_FUNC FILEIO * findid(FILEID id, int writable);
+E_FUNC int fgetposid(FILEID id, FILEPOS *ptr);
+E_FUNC int fsetposid(FILEID id, FILEPOS *ptr);
+E_FUNC int get_open_siz(FILE *fp, ZVALUE *res);
+E_FUNC char* findfname(FILEID);
+E_FUNC FILE *f_pathopen(char *name, char *mode, char *pathlist,
+			char **openpath);
 
 
-#endif /* !__FILE_H__ */
+#endif /* !INCLUDE_FILE_H */
